@@ -27,14 +27,16 @@
 #include <xapian.h>
 
 #include <KFileMetaData/Types>
-#include <QSqlDatabase>
 
 namespace Baloo {
 
+class XapianDocument;
+
 class BasicIndexingJob
 {
 public:
-    BasicIndexingJob(QSqlDatabase* db, const FileMapping& file, const QString& mimetype);
+    BasicIndexingJob(const FileMapping& file, const QString& mimetype,
+                     bool onlyBasicIndexing);
     ~BasicIndexingJob();
 
     bool index();
@@ -42,12 +44,20 @@ public:
     Xapian::Document document() { return m_doc; }
     uint id() { return m_id; }
 
+    /**
+     * Adds the data for all the extended attributes of \p url
+     * in the document \p doc
+     *
+     * \return Returns true if the \p doc was modified
+     */
+    static bool indexXAttr(const QString& url, XapianDocument& doc);
+
 private:
     QVector<KFileMetaData::Type::Type> typesForMimeType(const QString& mimeType) const;
 
-    QSqlDatabase* m_sqlDb;
     FileMapping m_file;
     QString m_mimetype;
+    bool m_onlyBasicIndexing;
 
     uint m_id;
     Xapian::Document m_doc;
