@@ -24,14 +24,10 @@
 #include <KPluginFactory>
 #include <KPluginLoader>
 #include <KAboutData>
-#include <KSharedConfig>
-#include <KDirWatch>
 #include <QDebug>
 #include <QStandardPaths>
 #include <KLocalizedString>
-#include <KConfigGroup>
 
-#include <QStyle>
 #include <QPushButton>
 #include <QDir>
 #include <QProcess>
@@ -39,6 +35,8 @@
 #include <QDBusMessage>
 #include <QDBusPendingCall>
 
+#include "indexerconfig.h"
+
 K_PLUGIN_FACTORY(BalooConfigModuleFactory, registerPlugin<Baloo::ServerConfigModule>();)
 K_EXPORT_PLUGIN(BalooConfigModuleFactory("kcm_baloofile"))
 
@@ -58,22 +56,26 @@ ServerConfigModule::ServerConfigModule(QWidget* parent, const QVariantList& args
     : KCModule(parent, args)
 {
     KAboutData* about = new KAboutData(
-        "kcm_baloofile", "kcm_baloofile", i18n("Configure Desktop Search"),
-        "0.1", QString(), KAboutData::License_GPL,
+        QLatin1String("kcm_baloofile"), i18n("Configure Desktop Search"),
+        QLatin1String("0.1"), QString(), KAboutLicense::GPL,
         i18n("Copyright 2007-2010 Sebastian Trüg"));
-    about->addAuthor(i18n("Sebastian Trüg"), QString(), "trueg@kde.org");
-    about->addAuthor(i18n("Vishesh Handa"), QString(), "vhanda@kde.org");
+    about->addAuthor(i18n("Sebastian Trüg"), QString(), QLatin1String("trueg@kde.org"));
+    about->addAuthor(i18n("Vishesh Handa"), QString(), QLatin1String("vhanda@kde.org"));
     setAboutData(about);
     setButtons(Help | Apply | Default);
 
     setupUi(this);
 
     int pixelSize = style()->pixelMetric(QStyle::PM_LargeIconSize);
-    QPixmap pixmap = QIcon::fromTheme("baloo").pixmap(QSize(pixelSize, pixelSize));
+    const QPixmap pixmap = QIcon::fromTheme(QLatin1String("baloo")).pixmap(QSize(pixelSize, pixelSize));
     m_pixmapLabel->setPixmap(pixmap);
 
     connect(m_folderSelectionWidget, SIGNAL(changed()),
             this, SLOT(changed()));
+    connect(m_folderSelectionWidget, SIGNAL(changed()),
+            this, SLOT(folderSelectionChanged()));
+    connect(m_enableCheckbox, SIGNAL(stateChanged(int)),
+            this, SLOT(changed()));
 }
 
 
@@ -84,12 +86,13 @@ ServerConfigModule::~ServerConfigModule()
 
 void ServerConfigModule::load()
 {
-    // File indexer settings
-    KConfig config("baloofilerc");
-    KConfigGroup group = config.group("General");
+    Baloo::IndexerConfig config;
 
-    QStringList includeFolders = group.readPathEntry("folders", defaultFolders());
-    QStringList excludeFolders = group.readPathEntry("exclude folders", QStringList());
+    m_previouslyEnabled = config.fileIndexingEnabled();
+    m_enableCheckbox->setChecked(m_previouslyEnabled);
+
+    QStringList includeFolders = config.includeFolders();
+    QStringList excludeFolders = config.excludeFolders();
     m_folderSelectionWidget->setFolders(includeFolders, excludeFolders);
 
     // All values loaded -> no changes
@@ -102,19 +105,23 @@ void ServerConfigModule::save()
     QStringList includeFolders = m_folderSelectionWidget->includeFolders();
     QStringList excludeFolders = m_folderSelectionWidget->excludeFolders();
 
-    // Change the settings
-    KConfig config("baloofilerc");
-    KConfigGroup basicSettings = config.group("Basic Settings");
+    bool mountPointsEx = m_folderSelectionWidget->allMountPointsExcluded();
 
-    bool indexingEnabled = !m_folderSelectionWidget->allMountPointsExcluded();
-    basicSettings.writeEntry("Indexing-Enabled", indexingEnabled);
+    bool enabled = m_enableCheckbox->isChecked();
+    if (mountPointsEx)
+        enabled = false;
 
-    // 2.2 Update normals paths
-    config.group("General").writePathEntry("folders", includeFolders);
-    config.group("General").writePathEntry("exclude folders", excludeFolders);
+    Baloo::IndexerConfig config;
+    config.setFileIndexingEnabled(enabled);
+    config.setIncludeFolders(includeFolders);
+    config.setExcludeFolders(excludeFolders);
+
+    if (m_previouslyEnabled != enabled) {
+        config.setFirstRun(true);
+    }
 
     // Start Baloo
-    if (indexingEnabled) {
+    if (enabled) {
         const QString exe = QStandardPaths::findExecutable(QLatin1String("baloo_file"));
         QProcess::startDetached(exe);
     }
@@ -141,4 +148,10 @@ void ServerConfigModule::defaults()
     m_folderSelectionWidget->setFolders(defaultFolders(), QStringList());
 }
 
+void ServerConfigModule::folderSelectionChanged()
+{
+    const bool disabled = m_folderSelectionWidget->allMountPointsExcluded();
+    m_enableCheckbox->setChecked(!disabled);
+}
+
 #include "kcm.moc"
