@@ -33,7 +33,7 @@ namespace Baloo {
 class FileSearchStore : public XapianSearchStore
 {
     Q_OBJECT
-    Q_PLUGIN_METADATA(IID "org.kde.baloo.file" FILE "baloofilesearchstore.json")
+    Q_PLUGIN_METADATA(IID "org.kde.baloo.file")
     Q_INTERFACES(Baloo::SearchStore)
 
 public:
@@ -62,7 +62,9 @@ private:
     QSqlDatabase m_sqlDb;
     QMutex m_sqlMutex;
 
-    QHash<QString, std::string> m_prefixes;
+    QHash<QString, QString> m_prefixes;
+
+    QString fetchPrefix(const QString& property) const;
 };
 
 }
